/*
 * Java-Gnome Bindings Library
 * 
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 * 
 * The Java-Gnome bindings library is free software distributed under the terms
 * of the GNU Library General Public License version 2.
 */
package org.gnu.gtk.event;

/**
 * This is the listener interface for receiving ComboBox events.
 * 
 * @see ComboBoxEvent
 */
public interface ComboBoxListener {

	/**
	 * Indicates that the <code>ComboBox</code> has fired an event.
	 * 
	 * @param event The event that identifies the details of the event.
	 */
	public void comboBoxEvent(ComboBoxEvent event);

}
